@@ -1,6 +1,7 @@
 import json
 from logging import getLogger
 
+from opentelemetry.semconv.trace import SpanAttributes
 from opentelemetry.trace import Span
 
 from helios.instrumentation.base import HeliosBaseInstrumentor
@@ -19,7 +20,15 @@ class HeliosRedisInstrumentor(HeliosBaseInstrumentor):
         if self.get_instrumentor() is None:
             return
 
-        self.get_instrumentor().instrument(tracer_provider=tracer_provider, response_hook=self.response_hook)
+        self.get_instrumentor().instrument(tracer_provider=tracer_provider,
+                                           request_hook=self.request_hook,
+                                           response_hook=self.response_hook)
+
+    def request_hook(self, span: Span, connection, args, kwargs):
+        # Default state serialization truncates it after 100 chars, so we override the behavior
+        db_statement = ' '.join([str(arg) for arg in args])
+        span.set_attribute(SpanAttributes.DB_STATEMENT, db_statement)
+        span.set_attribute(SpanAttributes.DB_SYSTEM, 'redis')
 
     def response_hook(self, span: Span, connection, response):
         if not span or not span.is_recording():
